summaryrefslogtreecommitdiff
path: root/src/cursor/cur_table.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/cursor/cur_table.c')
-rw-r--r--src/cursor/cur_table.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/cursor/cur_table.c b/src/cursor/cur_table.c
index 61c68246a4e..85024e5ce95 100644
--- a/src/cursor/cur_table.c
+++ b/src/cursor/cur_table.c
@@ -783,12 +783,13 @@ __wt_curtable_open(WT_SESSION_IMPL *session,
/*
* random_retrieval
* Random retrieval cursors only support next and close.
*/
WT_ERR(__wt_config_gets_defno(session, cfg, "next_random", &cval));
if (cval.val != 0) {
__wt_cursor_set_notsup(cursor);
cursor->next = __curtable_next_random;
+ cursor->reset = __curtable_reset;
}
STATIC_ASSERT(offsetof(WT_CURSOR_TABLE, iface) == 0);
@@ -783,12 +783,13 @@ __wt_curtable_open(WT_SESSION_IMPL *session,
/*
* random_retrieval
- * Random retrieval cursors only support next and close.
+ * Random retrieval cursors only support next, reset and close.
*/
WT_ERR(__wt_config_gets_defno(session, cfg, "next_random", &cval));